tik_get_advertiser_balance: Get the Balance and Budget of Ad Accounts
Description
Use this endpoint to obtain the balance of ad accounts in the Business Center. You can also use this endpoint to obtain the budget of the ad accounts owned by the Business Center in auto-allocation mode.
Usage
tik_get_advertiser_balance(bc_id, fields = NULL)
Value
tibble with balance and budget info
Arguments
bc_id
Business Center ID.
fields
A list of additional fields to return in the response. Supported values:
budget_remaining: The remaining budget.
budget_frequency_restriction: Restrictions on the number of budget changes allowed for the current day.
budget_amount_restriction: Restrictions on the minimum amount that can be changed for the budget.
min_transferable_amount: Details of the minimal amount that you can transfer to the ad account.